Examples
========

To help get you started using ``powerbox``, we've compiled a few simple examples.
Other examples can be found in the :doc:`API documentation <api>` for each object or by looking at some of the tests.

.. toctree::
   :maxdepth: 2

   demos/getting_started
   demos/algorithm
   demos/cosmological_fields
   demos/dft
   demos/mpi
